@@ -149,7 +149,8 @@ QList<KBookmarkOwner::FutureBookmark> BookmarkHandler::currentBookmarkList() con
     QList<KBookmarkOwner::FutureBookmark> list;
     list.reserve(_views.size());
 
-    foreach (ViewProperties *view, _views) {
+    const QList<ViewProperties *> views = _views;
+    for (ViewProperties* view : views) {
         list << KBookmarkOwner::FutureBookmark(titleForView(view), urlForView(view), iconForView(view));
     }
 
