@@ -109,7 +109,7 @@ void Emulation::checkSelectedText()
 
 Emulation::~Emulation()
 {
-    foreach (ScreenWindow *window, _windows) {
+    for (ScreenWindow *window : qAsConst(_windows)) {
         delete window;
     }
 
@@ -124,7 +124,7 @@ void Emulation::setScreen(int index)
     _currentScreen = _screen[index & 1];
     if (_currentScreen != oldScreen) {
         // tell all windows onto this emulation to switch to the newly active screen
-        foreach (ScreenWindow *window, _windows) {
+        for (ScreenWindow *window : qAsConst(_windows)) {
             window->setScreen(_currentScreen);
         }
 
