@@ -731,7 +731,7 @@ void Screen::displayCharacter(uint c)
             Q_ASSERT(oldChars);
             if (((oldChars) != nullptr) && extendedCharLength < 3) {
                 Q_ASSERT(extendedCharLength > 1);
-                Q_ASSERT(extendedCharLength < 65535);
+                Q_ASSERT(extendedCharLength < 65535); // redundant due to above check
                 auto chars = new uint[extendedCharLength + 1];
                 memcpy(chars, oldChars, sizeof(uint) * extendedCharLength);
                 chars[extendedCharLength] = c;
@@ -1227,15 +1227,6 @@ bool Screen::isSelectionValid() const
     return _selTopLeft >= 0 && _selBottomRight >= 0;
 }
 
-void Screen::writeSelectionToStream(TerminalCharacterDecoder* decoder ,
-                                    const DecodingOptions options) const
-{
-    if (!isSelectionValid()) {
-        return;
-    }
-    writeToStream(decoder, _selTopLeft, _selBottomRight, options);
-}
-
 void Screen::writeToStream(TerminalCharacterDecoder* decoder,
                            int startIndex, int endIndex,
                            const DecodingOptions options) const
