@@ -85,7 +85,7 @@ public:
      * variable.
      */
     explicit Session(QObject *parent = nullptr);
-    ~Session() Q_DECL_OVERRIDE;
+    ~Session() override;
 
     /**
      * Connect to an existing terminal.  When a new Session() is constructed it
@@ -349,7 +349,7 @@ public:
     /**
       * Possible values of the @p what parameter for setSessionAttribute().
       * See the "Operating System Commands" section at:
-      * http://invisible-island.net/xterm/ctlseqs/ctlseqs.html#h2-Operating-System-Commands
+      * https://invisible-island.net/xterm/ctlseqs/ctlseqs.html#h3-Operating-System-Commands
       */
     enum SessionAttributes {
         IconNameAndWindowTitle = 0,
@@ -372,6 +372,8 @@ public:
 
     void sendSignal(int signal);
 
+    void reportColor(SessionAttributes r, const QColor &c);
+    void reportForegroundColor(const QColor &c);
     void reportBackgroundColor(const QColor &c);
 
     bool isReadOnly() const;
@@ -697,6 +699,12 @@ Q_SIGNALS:
      */
     void selectionChanged(const QString &text);
 
+    /**
+     * Emitted when foreground request ("\033]10;?\a") terminal code received.
+     * Terminal is expected send "\033]10;rgb:RRRR/GGGG/BBBB\a" response.
+     */
+    void getForegroundColor();
+
     /**
      * Emitted when background request ("\033]11;?\a") terminal code received.
      * Terminal is expected send "\033]11;rgb:RRRR/GGGG/BBBB\a" response.
@@ -840,7 +848,7 @@ public:
     /** Constructs an empty session group. */
     explicit SessionGroup(QObject *parent);
     /** Destroys the session group and removes all connections between master and slave sessions. */
-    ~SessionGroup() Q_DECL_OVERRIDE;
+    ~SessionGroup() override;
 
     /** Adds a session to the group. */
     void addSession(Session *session);
@@ -859,8 +867,6 @@ public:
      * @param master True to make this session a master or false otherwise
      */
     void setMasterStatus(Session *session, bool master);
-    /** Returns the master status of a session.  See setMasterStatus() */
-    bool masterStatus(Session *session) const;
 
     /**
      * This enum describes the options for propagating certain activity or
@@ -881,19 +887,12 @@ public:
      * @param mode A bitwise OR of MasterMode flags.
      */
     void setMasterMode(int mode);
-    /**
-     * Returns a bitwise OR of the active MasterMode flags for this group.
-     * See setMasterMode()
-     */
-    int masterMode() const;
 
 private Q_SLOTS:
     void sessionFinished();
     void forwardData(const QByteArray &data);
 
 private:
-    QList<Session *> masters() const;
-
     // maps sessions to their master status
     QHash<Session *, bool> _sessions;
 
