@@ -246,10 +246,15 @@ void ViewManager::setupActions()
 
     // _viewSplitter->addAction(lastUsedViewReverseAction);
     const int SWITCH_TO_TAB_COUNT = 19;
-    for (int i = 0; i < SWITCH_TO_TAB_COUNT; i++) {
+    for (int i = 0; i < SWITCH_TO_TAB_COUNT; ++i) {
         action = new QAction(i18nc("@action Shortcut entry", "Switch to Tab %1", i + 1), this);
         connect(action, &QAction::triggered, this, [this, i]() { switchToView(i); });
         collection->addAction(QStringLiteral("switch-to-tab-%1").arg(i), action);
+
+        // only add default shortcut bindings for the first 9 tabs, regardless of SWITCH_TO_TAB_COUNT
+        if (i < 9) {
+            collection->setDefaultShortcut(action, QStringLiteral("Alt+%1").arg(i + 1));
+        }
     }
 
     connect(_viewContainer, &TabbedViewContainer::viewAdded, this, &ViewManager::toggleActionsBasedOnState);
@@ -261,7 +266,7 @@ void ViewManager::setupActions()
 
 void ViewManager::toggleActionsBasedOnState() {
     const int count = _viewContainer->count();
-    foreach(QAction *tabOnlyAction, _multiTabOnlyActions) {
+    for (QAction *tabOnlyAction : qAsConst(_multiTabOnlyActions)) {
         tabOnlyAction->setEnabled(count > 1);
     }
 
@@ -272,7 +277,7 @@ void ViewManager::toggleActionsBasedOnState() {
                 ->findChildren<TerminalDisplay*>()
                     .count();
 
-        foreach (QAction *action, _multiSplitterOnlyActions) {
+        for (QAction *action : qAsConst(_multiSplitterOnlyActions)) {
             action->setEnabled(splitCount > 1);
         }
     }
@@ -422,7 +427,8 @@ void ViewManager::detachTab(int tabIdx)
 QHash<TerminalDisplay*, Session*> ViewManager::forgetAll(ViewSplitter* splitter) {
     splitter->setParent(nullptr);
     QHash<TerminalDisplay*, Session*> detachedSessions;
-    foreach(TerminalDisplay* terminal, splitter->findChildren<TerminalDisplay*>()) {
+    const QList<TerminalDisplay *> displays = splitter->findChildren<TerminalDisplay*>();
+    for (TerminalDisplay *terminal : displays) {
         Session* session = forgetTerminal(terminal);
         detachedSessions[terminal] = session;
     }
@@ -826,7 +832,7 @@ void ViewManager::updateViewsForSession(Session *session)
     const Profile::Ptr profile = SessionManager::instance()->sessionProfile(session);
 
     const QList<TerminalDisplay *> sessionMapKeys = _sessionMap.keys(session);
-    foreach (TerminalDisplay *view, sessionMapKeys) {
+    for (TerminalDisplay *view : sessionMapKeys) {
         applyProfileToView(view, profile);
     }
 }
@@ -918,14 +924,14 @@ namespace {
 
 ViewSplitter *restoreSessionsSplitterRecurse(const QJsonObject& jsonSplitter, ViewManager *manager)
 {
-    auto splitterWidgets = jsonSplitter[QStringLiteral("Widgets")].toArray();
-    auto orientation = (jsonSplitter[QStringLiteral("Orientation")].toString() == QLatin1String("Horizontal"))
+    const QJsonArray splitterWidgets = jsonSplitter[QStringLiteral("Widgets")].toArray();
+    auto orientation = (jsonSplitter[QStringLiteral("Orientation")].toString() == QStringLiteral("Horizontal"))
         ? Qt::Horizontal : Qt::Vertical;
 
     auto *currentSplitter = new ViewSplitter();
     currentSplitter->setOrientation(orientation);
 
-    for (const auto& widgetJsonValue : splitterWidgets) {
+    for (const auto widgetJsonValue : splitterWidgets) {
         const auto widgetJsonObject = widgetJsonValue.toObject();
         const auto sessionIterator = widgetJsonObject.constFind(QStringLiteral("SessionRestoreId"));
 
@@ -960,7 +966,8 @@ void ViewManager::restoreSessions(const KConfigGroup &group)
     TerminalDisplay *display = nullptr;
 
     int tab = 1;
-    foreach (int id, ids) {
+    for (auto it = ids.cbegin(); it != ids.cend(); ++it) {
+        const int &id = *it;
         Session *session = SessionManager::instance()->idToSession(id);
 
         if (session == nullptr) {
